import { Cell, CellGroup, Icon } from 'vant'
import { defineComponent, PropType } from 'vue'
import styles from './index.module.less'

import courseIntroduction from '@common/images/icon_course_introduction.png'
import courseList from '@common/images/icon_course_list.png'

type IconType = 'courseIntroduction' | 'courseList'

export default defineComponent({
  name: 'SectionDetail',
  props: {
    icon: {
      type: String as PropType<'courseIntroduction' | 'courseList'>,
      default: 'courseIntroduction'
    },
    title: {
      type: String,
      default: '课程介绍'
    },
    border: {
      type: Boolean,
      default: false
    },
    titleShow: {
      // 是否显示标题
      type: Boolean,
      default: true
    },
    contentClass: {
      type: String
    },
    contentStyle: {
      type: Object
    }
  },
  render() {
    return (
      <div class={styles['section-detail']}>
        <CellGroup border={this.border}>
          {this.titleShow ? (
            <Cell
              center
              border={this.border}
              v-slots={{
                icon: () => (
                  <Icon
                    name={
                      this.icon === 'courseIntroduction'
                        ? courseIntroduction
                        : courseList
                    }
                    size="18"
                  />
                ),
                title: () => <div class={styles.name}>{this.title}</div>
              }}
            ></Cell>
          ) : null}
          <Cell center class={this.contentClass} style={this.contentStyle}>
            {this.$slots.default && this.$slots.default()}
          </Cell>
        </CellGroup>
      </div>
    )
  }
})
