import ColHeader from '@/components/col-header'
import { Button, Cell, Icon, Image } from 'vant'
import { defineComponent } from 'vue'
import styles from './index.module.less'
import ColProtocol from '@/components/col-protocol'

import iconTeacher from '@common/images/icon_teacher.png'

export const getAssetsHomeFile = (fileName: string) => {
  const path = `./images/${fileName}`
  const modules = import.meta.globEager('./images/*')
  return modules[path].default
}

export default defineComponent({
  name: 'MemberCenter',
  data() {
    return {
      agreeStatus: false,
      functionList: [
        { title: '五线谱<br />跟播', icon: getAssetsHomeFile('1.png') },
        { title: '演奏指法<br />跟播', icon: getAssetsHomeFile('2.png') },
        { title: '原声/伴奏<br />切换', icon: getAssetsHomeFile('3.png') },
        { title: '播放速度<br />调整', icon: getAssetsHomeFile('4.png') },
        { title: '五线谱选段<br />播放', icon: getAssetsHomeFile('5.png') },
        { title: '智能评测', icon: getAssetsHomeFile('6.png') },
        { title: '评测报告', icon: getAssetsHomeFile('7.png') },
        { title: '评测音视频<br />云储存', icon: getAssetsHomeFile('8.png') }
      ]
    }
  },
  methods: {
    onSubmit() {
      this.$router.push({
        path: '/orderDetail',
        query: {
          type: 'VIP'
        }
      })
    }
  },
  render() {
    return (
      <div class={styles['member-center']}>
        <ColHeader isFixed={false} background="transparent" />
        <div class={styles.member_container}>
          <Cell
            class={styles.userMember}
            labelClass={styles.timeRemaining}
            v-slots={{
              icon: () => (
                <div class={styles.userImgSection}>
                  <Image class={styles.userImg} src={iconTeacher} fit="cover" />
                </div>
              ),
              title: () => (
                <div class={styles.userInfo}>
                  <span class={styles.name}>李小明</span>
                  <Image
                    class={styles.level}
                    src="https://daya.ks3-cn-beijing.ksyun.com/202107/ScSTL1D.png"
                  />
                  <span class={styles.phone} v-html="（15907121013）"></span>
                </div>
              ),
              label: () => (
                <div class={styles.member_time}>
                  {true ? (
                    <div>
                      {' '}
                      会员权益有效期剩余
                      <span class={styles.remaining}>200</span>天
                    </div>
                  ) : (
                    <div>亲，您还不是会员哟</div>
                  )}
                </div>
              )
            }}
          ></Cell>
        </div>

        <div class={styles.memberContainer}>
          <div class={styles.memberItem}>
            <div class={styles.title}>
              会员<span>VIP</span>
            </div>

            <div class={styles['system-list']}>
              <div class={[styles['system-item'], styles.active]}>
                <p class={styles.title}>月度会员</p>
                <p class={styles.price}>
                  <span>￥</span>199
                </p>
                <del class={styles.originalPrice}>￥199</del>
              </div>

              <div class={styles['system-item']}>
                <p class={styles.title}>月度会员</p>
                <p class={styles.price}>
                  <span>￥</span>199
                </p>
                <del class={styles.originalPrice}>￥199</del>
              </div>

              <div class={styles['system-item']}>
                <p class={styles.title}>月度会员</p>
                <p class={styles.price}>
                  <span>￥</span>199
                </p>
                <del class={styles.originalPrice}>￥199</del>
              </div>

              <div class={styles['system-item']}>
                <p class={styles.title}>月度会员</p>
                <p class={styles.price}>
                  <span>￥</span>199
                </p>
                <del class={styles.originalPrice}>￥199</del>
              </div>
            </div>
          </div>

          <div class={[styles.intro]}>
            <p>
              黄金会员使用包括平台提供教材的所有训练乐谱，并专享“
              <b>乐器练习云教练</b>
              ”八大核心功能，孩子在家就能轻松完成乐器自主规范练习。
            </p>
          </div>

          <div class={styles.memberItem}>
            <div class={styles.title}>会员功能</div>

            <div class={styles.member_function}>
              {this.functionList.map((item: any) => (
                <div class={styles.function_item}>
                  <Icon name={item.icon} size={34} />
                  <div class={styles.function_text} v-html={item.title}></div>
                </div>
              ))}
            </div>
          </div>

          <ColProtocol
            v-model={this.agreeStatus}
            style={{ paddingLeft: 0, paddingRight: 0, marginBottom: '20px' }}
          />
        </div>
        <div class={styles.btnGroup}>
          <div class={styles.priceSection}>
            支付金额：
            <div class={styles.price}>
              <span class={styles.priceUnit}>￥</span>
              <span class={styles.priceNum}>
                {(this as any).$filters.moneyFormat(99)}
              </span>
            </div>
          </div>
          <Button
            color="linear-gradient(220deg, #DFA164 0%, #FAC87E 100%)"
            round
            class={styles.btn}
            onClick={this.onSubmit}
          >
            立即支付
          </Button>
        </div>
      </div>
    )
  }
})
