import ColHeader from '@/components/col-header'
import { defineComponent } from 'vue'
import styles from './member-record.module.less'
import { Cell, CellGroup, Grid, GridItem, Icon, Image, Sticky } from 'vant'

export const getAssetsHomeFile = (fileName: string) => {
  const path = `./images/${fileName}`
  const modules = import.meta.globEager('./images/*')
  return modules[path].default
}

export default defineComponent({
  name: 'memberRecord',
  render() {
    return (
      <div class={styles['member-record']}>
        <Sticky position="top" offsetTop={0}>
          <ColHeader
            class={styles.memberHeader}
            background="#00d1a1"
            border={false}
            color="#fff"
            isFixed={false}
            v-slots={{
              default: () => (
                <div class={styles.headerContent}>
                  <Image
                    class={styles.headerImg}
                    src={getAssetsHomeFile('record_bg.png')}
                  />

                  <div class={styles.headerCount}>
                    <div class={styles.headerItem}>
                      <span class={styles.num}>142</span>
                      <span>累计训练天数</span>
                    </div>
                    <div class={styles.headerItem}>
                      <span class={styles.num}>95</span>
                      <span>累计训练时长</span>
                    </div>
                    <div class={styles.headerItem}>
                      <span class={styles.num}>142</span>
                      <span>累计训练次数</span>
                    </div>
                  </div>
                </div>
                //   <div class={[styles.certHeader, this.headStatus ? styles.certWhite : null]}>
                //     老师认证
                //   </div>
              )
            }}
          />
        </Sticky>

        <div style={{ overflow: 'hidden', paddingBottom: '12px' }}>
          <Cell
            class={styles.memberCell}
            v-slots={{
              title: () => (
                <div class={styles.rTitle}>
                  <span>评测记录</span>
                </div>
              ),
              default: () => (
                <div class={styles.dataItem}>
                  2022年4月13日
                  <Icon
                    classPrefix="iconfont"
                    name="down"
                    size={8}
                    color="var(--van-primary)"
                  />
                </div>
              )
            }}
          ></Cell>

          {[1, 2, 3, 4, 5].map(item => (
            <CellGroup class={styles['data-content']} border={false}>
              <Cell
                center
                v-slots={{
                  title: () => (
                    <div class={styles.dataTitle}>
                      <span>长笛教程1-2</span>
                      <Icon
                        name={getAssetsHomeFile('icon_video.png')}
                        size={20}
                      />
                    </div>
                  ),
                  default: () => (
                    <div class={styles.dataItem}>2022年4月13日09:47:38</div>
                  )
                }}
              ></Cell>
              <Cell
                center
                style={{ paddingLeft: '5px', paddingRight: '5px' }}
                v-slots={{
                  title: () => (
                    <Grid border={false} columnNum={5} clickable>
                      <GridItem
                        text="评测难度"
                        v-slots={{
                          icon: () => (
                            <span style={{ color: '#000000' }}>入门级</span>
                          )
                        }}
                      ></GridItem>
                      <GridItem
                        text="评测分数"
                        v-slots={{
                          icon: () => (
                            <span style={{ color: '#000000' }}>40分</span>
                          )
                        }}
                      ></GridItem>
                      <GridItem
                        text="音准"
                        v-slots={{
                          icon: () => (
                            <span style={{ color: '#01C1B5' }}>20分</span>
                          )
                        }}
                      ></GridItem>
                      <GridItem
                        text="节奏"
                        v-slots={{
                          icon: () => (
                            <span style={{ color: '#FF802C' }}>22份</span>
                          )
                        }}
                      ></GridItem>
                      <GridItem
                        text="完成度"
                        v-slots={{
                          icon: () => (
                            <span style={{ color: '#F79C00' }}>45分</span>
                          )
                        }}
                      ></GridItem>
                    </Grid>
                  )
                }}
              ></Cell>
            </CellGroup>
          ))}
        </div>
      </div>
    )
  }
})
