import { defineComponent, PropType } from 'vue'
import styles from './index.module.less'
import {
  ActionSheet,
  Cell,
  CellGroup,
  DatetimePicker,
  Icon,
  Popup,
  Sticky,
  Image
} from 'vant'
import { formatterDate } from '@/helpers/utils'

import iconTeacher from '@common/images/icon_teacher.png'

export default defineComponent({
  name: 'list',
  props: {
    type: {
      type: String as PropType<'buy' | 'refund'>,
      default: 'buy'
    }
  },
  data() {
    return {
      timeStatus: false,
      currentDate: new Date(),
      typeStatus: false,
      actions: [{ name: '全部' }, { name: '已完成' }, { name: '未完成' }]
    }
  },
  methods: {
    onDetail(item: any) {
      this.$router.push({
        path: '/tradeDetail'
      })
    },
    onConfirm(date: Date) {
      this.currentDate = date
      this.timeStatus = false
    }
  },
  render() {
    return (
      <div class={styles.tradeList}>
        <Sticky offsetTop={44} position="top">
          <Cell
            center
            style={{ backgroundColor: '#F7F8F9' }}
            v-slots={{
              title: () => (
                <div
                  class={styles.searchTime}
                  onClick={() => {
                    this.timeStatus = true
                  }}
                >
                  <span>
                    {(this as any).$filters.dateFormat(
                      this.currentDate,
                      'YYYY-MM-DD'
                    )}
                  </span>
                  <Icon
                    classPrefix="iconfont"
                    name="down"
                    size={8}
                    color="var(--van-primary)"
                  />
                </div>
              ),
              value: () => (
                <div
                  class={styles.searchType}
                  onClick={() => {
                    this.typeStatus = true
                  }}
                >
                  <span>全部</span>
                  <Icon
                    classPrefix="iconfont"
                    name="down"
                    size={8}
                    color="var(--van-primary)"
                  />
                </div>
              )
            }}
          ></Cell>
        </Sticky>

        <div class={styles.list}>
          <CellGroup onClick={this.onDetail}>
            <Cell
              title="2022-3-25 18:56"
              value="交易成功"
              valueClass={styles.tradeType}
            />
            <Cell
              v-slots={{
                icon: () => (
                  <Image
                    class={styles.tradeLogo}
                    src={iconTeacher}
                    fit="cover"
                  />
                ),
                title: () => (
                  <div class={styles.title}>
                    <span>购买课程</span>
                    <span class={styles.desc}>会员缴费</span>
                  </div>
                ),
                default: () => (
                  <div class={styles.content}>
                    <span class={styles.price}>￥100</span>
                    <span class={styles.num}>x1</span>
                  </div>
                )
              }}
            />
          </CellGroup>
        </div>

        <Popup show={this.timeStatus} position="bottom" round closeOnPopstate>
          <DatetimePicker
            type="date"
            v-model={this.currentDate}
            formatter={formatterDate}
            onCancel={() => {
              this.timeStatus = false
            }}
            onConfirm={this.onConfirm}
          />
        </Popup>

        <ActionSheet
          v-model:show={this.typeStatus}
          actions={this.actions}
          closeOnClickAction
          cancelText="取消"
          onCancel={() => {
            this.typeStatus = false
          }}
        />
      </div>
    )
  }
})
