import ColHeader from '@/components/col-header'
import { Cell, CellGroup, Col, Image, Row } from 'vant'
import { defineComponent } from 'vue'
import styles from './trade-detail.module.less'

import iconTeacher from '@common/images/icon_teacher.png'

export const getAssetsHomeFile = (fileName: string) => {
  const path = `./images/${fileName}`
  const modules = import.meta.globEager('./images/*')
  return modules[path].default
}

type orderType = 'ING' | 'SUCCESS' | 'FAILED'

export default defineComponent({
  name: 'tradeDetail',
  data() {
    const query = this.$route.query
    return {
      type: (query.type as string) || 'ING',
      orderNo: query.orderNo || '',
      order: {
        ING: {
          img: getAssetsHomeFile('icon_paying.png'),
          background: '#FF802C'
        },
        SUCCESS: {
          img: getAssetsHomeFile('icon_success.png'),
          background: 'var(--van-primary)'
        },
        FAILED: {
          img: getAssetsHomeFile('icon_close.png'),
          background: '#BDBDBD'
        }
      }
    }
  },
  render() {
    return (
      <div class={[styles.tradeDetail, styles[this.type]]}>
        <ColHeader
          background={this.order[this.type].background}
          color="#fff"
          title="交易详情"
          border={false}
        />

        <div class={styles.orderType}>
          <p>
            <Image
              class={styles.orderImg}
              src={this.order[this.type].img}
              fit="cover"
            />
            <span>交易成功</span>
          </p>
        </div>

        <CellGroup border={false} class={styles.orderContent}>
          <Cell
            v-slots={{
              title: () => (
                <div class={styles.payPrice}>
                  <span>￥</span>160
                </div>
              )
            }}
          />
          <Cell
            border={false}
            style={{ paddingBottom: '15px' }}
            v-slots={{
              icon: () => (
                <Image class={styles.tradeLogo} src={iconTeacher} fit="cover" />
              ),
              title: () => (
                <div class={styles.title}>
                  <span>购买课程</span>
                  <span class={styles.desc}>会员缴费</span>
                </div>
              ),
              default: () => (
                <div class={styles.content}>
                  <span class={styles.price}>￥100</span>
                  <span class={styles.num}>x1</span>
                </div>
              )
            }}
          />

          <Row class={styles.optionRow}>
            <Col span="8" offset={1}>
              订单号:
            </Col>
            <Col span="14">12</Col>
            <Col span="1"> </Col>
          </Row>
          <Row class={styles.optionRow}>
            <Col span="8" offset={1}>
              交易流水号:
            </Col>
            <Col span="14">12</Col>
            <Col span="1"> </Col>
          </Row>
          <Row class={styles.optionRow}>
            <Col span="8" offset={1}>
              创建时间:
            </Col>
            <Col span="14">12</Col>
            <Col span="1"> </Col>
          </Row>
          <Row class={styles.optionRow}>
            <Col span="8" offset={1}>
              付款时间:
            </Col>
            <Col span="14">12</Col>
            <Col span="1"> </Col>
          </Row>
          <Row class={styles.optionRow}>
            <Col span="8" offset={1}>
              付款时间:
            </Col>
            <Col span="14">12</Col>
            <Col span="1"> </Col>
          </Row>
        </CellGroup>
      </div>
    )
  }
})
