import ColProtocol from '@/components/col-protocol'
import { Button, Icon, Popup, Sticky, Toast } from 'vant'
import ColPopup from '@/components/col-popup'
import { defineComponent } from 'vue'
import { postMessage } from '@/helpers/native-message'
import styles from './index.module.less'
import OrderVideo from './order-video'
import OrderLive from './order-live'
import UserAuth from './userAuth'

// 调用原生支付
// postMessage({ api: 'paymentOrder', content: { orderNo: 0 } })
// listenerMessage({ api: 'paymentResult', callback: (res: any) => {
//   status: 'success | fail'
// }})

import iconTips from '@common/images/icon_tips.png'
import Payment from './payment'

export default defineComponent({
  name: 'order-detail',
  data() {
    const query = this.$route.query
    return {
      orderType: query.orderType,
      agreeStatus: false,
      popupShow: false,
      paymentStatus: false,
      orderPrice: 0 // 支付金额
    }
  },
  methods: {
    onAuthSuccess() {
      console.log('auth success')
      this.popupShow = false
    },
    async onSubmit() {
      // this.popupShow = true
      if (!this.agreeStatus) {
        Toast('请先阅读并同意《酷乐秀平台服务协议》')
        return
      }
      // return
      console.log('submit', this.$refs.orderVideo)
      if (this.$refs.orderVideo && this.orderType == 'VIDEO') {
        const result = await (this as any).$refs.orderVideo.onSubmit()
        console.log(result)
      } else if (this.$refs.orderLive && this.orderType == 'LIVE') {
        const result = await (this as any).$refs.orderLive.onSubmit()
        if (result) {
          console.log(result)
        }
        console.log(result)
      }
    }
  },
  render() {
    return (
      <div class={styles['order-detail']}>
        {this.orderType === 'LIVE' && (
          <OrderLive ref="orderLive" v-model={this.orderPrice} />
        )}
        {this.orderType === 'VIDEO' && (
          <OrderVideo ref="orderVideo" v-model={this.orderPrice} />
        )}

        <div class={styles.tips}>
          <h3>
            <Icon name={iconTips} size={15} />
            温馨提示
          </h3>

          <p>
            1、您支付的课酬费用将由平台收取 <br />
            2、课程结束7天后，平台将单课时费用向老师结算
          </p>
        </div>

        <ColProtocol
          v-model={this.agreeStatus}
          style={{ paddingLeft: 0, paddingRight: 0 }}
        />
        <div class={styles.btnGroup}>
          <div class={styles.priceSection}>
            支付金额：
            <div class={styles.price}>
              <span class={styles.priceUnit}>￥</span>
              <span class={styles.priceNum}>
                {(this as any).$filters.moneyFormat(this.orderPrice)}
              </span>
            </div>
          </div>
          <Button
            type="primary"
            round
            class={styles.btn}
            onClick={this.onSubmit}
          >
            立即支付
          </Button>
        </div>

        <ColPopup v-model={this.popupShow}>
          <UserAuth onSuccess={this.onAuthSuccess} />
        </ColPopup>

        <Popup
          show={this.paymentStatus}
          closeOnClickOverlay={false}
          position="bottom"
          round
          closeOnPopstate
          safeAreaInsetBottom
          style={{ minHeight: '30%' }}
        >
          <Payment v-model={this.paymentStatus} />
        </Popup>
      </div>
    )
  }
})
