import {
  Button,
  Cell,
  CellGroup,
  Icon,
  RadioGroup,
  Radio,
  Dialog,
  Toast
} from 'vant'
import { defineComponent } from 'vue'
import styles from './index.module.less'

import checkBoxActive from '@/teacher/teacher-cert/images/checkbox_active.png'
import checkBoxDefault from '@/teacher/teacher-cert/images/checkbox_default.png'

export default defineComponent({
  name: 'payment',
  props: {
    modelValue: {
      type: Boolean,
      default: false
    },
    onBackOut: {
      type: Function,
      default: () => {}
    }
  },
  data() {
    return {
      payType: 'zfb',
      pay_channel: ''
    }
  },
  methods: {
    onClose() {
      Dialog.confirm({
        message: '是否放弃本次付款',
        confirmButtonText: '继续付款',
        cancelButtonText: '放弃'
      })
        .then(() => {})
        .catch(() => {
          this.$emit('update:modelValue', false)
          this.onBackOut && this.onBackOut()
        })
    },
    onSubmit() {
      // 支付...
      const pt = this.payType,
        ua = window.navigator.userAgent.toLowerCase()
      // 判断当前浏览器
      if (ua.indexOf('micromessenger') != -1) {
        // 微信浏览器
        if (pt == 'zfb') {
          this.pay_channel = 'alipay_qr'
        } else if (pt == 'wx') {
          this.pay_channel = 'wx_pub'
        }
      } else if (ua.indexOf('alipayclient') != -1) {
        // 支付宝浏览器
        if (pt == 'zfb') {
          this.pay_channel = 'alipay_wap'
          // 支付宝 H5 支付
        } else if (pt == 'wx') {
          this.pay_channel = 'wx_pub'
        }
      } else {
        if (pt == 'zfb') {
          this.pay_channel = 'alipay_qr'
        } else if (pt == 'wx') {
          this.pay_channel = 'wx_pub'
        }
      }

      Toast('支付成功')
      this.$emit('update:modelValue', false)
    }
  },
  render() {
    return (
      <div class={styles.payment}>
        <Icon onClick={this.onClose} name="cross" size={20} />
        <div class={[styles.title, 'van-hairline--bottom']}>选择支付方式</div>

        <div class={styles.payAmount}>
          <p>应付金额</p>
          <div class={styles.amount}>
            154<span>元</span>
          </div>
        </div>
        <RadioGroup v-model={this.payType}>
          <CellGroup border={false}>
            <Cell
              title="支付宝支付"
              border={false}
              center
              onClick={() => {
                this.payType = 'zfb'
              }}
              v-slots={{
                icon: () => <Icon name="alipay" color="#009fe9" size={22} />,
                'right-icon': () => <Radio name="zfb" />
              }}
            ></Cell>
            <Cell
              title="微信支付"
              border={false}
              center
              onClick={() => {
                this.payType = 'wx'
              }}
              v-slots={{
                icon: () => (
                  <Icon name="wechat-pay" color="#15c434" size={22} />
                ),
                'right-icon': () => <Radio name="wx" />
              }}
            ></Cell>
            {/* v-slots={{
                      icon: (props: any) => (
                        <Icon
                          name={
                            props.checked ? checkBoxActive : checkBoxDefault
                          }
                          size="22"
                        />
                      )
                    }} */}
          </CellGroup>
        </RadioGroup>

        <div class={styles.blank}></div>
        <Button type="primary" block onClick={this.onSubmit}>
          确认支付
        </Button>
      </div>
    )
  }
})
